Geospatial Urban API Service
============================
Direct access to simulated spatially enabled traffic grids of urban regions.

This modern Python module represents an idiomatic client accessing the `Geospatial Urban API <https://geospatial-ai.de/?rara-portfolio=geospatial-urban-api-service>`__ being hosted on `Rapid API Hub <https://rapidapi.com/hub>`__.

Why is it important?
--------------------
The geospatial urban API solves a common challenge for urban digital twins - 
obtaining insights into mobility behavior of citizens using simulated traffic scenarios. 
Traffic planners use powerful tools in shaping urban mobility sustainable. 
But without having access to citizen movement profiles there is always a need for simulating, analyzing, testing and mitigating traffic scenarios.

Next steps
----------
Please, check out the `RapidAPI Account Creation and Management Guide <https://docs.rapidapi.com/docs/account-creation-and-settings>`__.

.. note::

   This project is under active development.

Contents
--------

.. toctree::
   usage
   guides
   api
